//--------------------------------------------------------------------------
//
// Environment:
//      This software is part of the EvtGen package developed jointly
//      for the BaBar and CLEO collaborations.  If you use all or part
//      of it, please give an appropriate acknowledgement.
//
// Copyright Information: See EvtGen/COPYRIGHT
//      Copyright (C) 1998      Caltech, UCSB
//
// Module: EvtGen/EvtStringParticle.hh
//
// Description: EvtStringParticle particle is a class to keep the
//              collection of partons that are generated by jetset.
//              This is supposedly the _only_ use of this particle.
//
// Modification history:
//
//    RYD     Febuary 27, 1998         Module created
//
//------------------------------------------------------------------------

#ifndef EVTSTRINGPARTICLE_HH
#define EVTSTRINGPARTICLE_HH

#include "EvtGenBase/EvtParticle.hh"
#include "EvtGenBase/EvtId.hh"

class EvtStringParticle:public EvtParticle {

public:

  EvtStringParticle();
  virtual ~EvtStringParticle();
  void init(EvtId id, const EvtVector4R& p4);
  void initPartons(int npartons,EvtVector4R* p4partons,EvtId* idpartons);
  int getNPartons();
  EvtId getIdParton(int i);
  EvtVector4R getP4Parton(int i);
  EvtSpinDensity rotateToHelicityBasis() const;
  EvtSpinDensity rotateToHelicityBasis(double alpha,
				       double beta,
				       double gamma) const;

private:

  int _npartons;

  EvtVector4R* _p4partons;
  EvtId* _idpartons;

  EvtStringParticle& operator=(const EvtStringParticle& d);

};
#endif

